# Metacritic Scraper 

A webscraper which collects information from the website metacritic.com. 

# Running the application 

1. Create an RDS and fill out the details within the rds_details_config.yaml file. * 
2. Run main.py in the terminal 

# Future Improvements 

- Adding functionality to scrape from other genres on the website. 



